% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/assert-is-whole-number.R, R/is-whole-number.R
\name{assert_all_numbers_are_whole_numbers}
\alias{assert_all_are_whole_numbers}
\alias{assert_all_numbers_are_whole_numbers}
\alias{assert_any_are_whole_numbers}
\alias{assert_any_numbers_are_whole_numbers}
\alias{is_whole_number}
\title{Is the input a whole number?}
\usage{
assert_all_numbers_are_whole_numbers(x, tol = 100 * .Machine$double.eps,
  na_ignore = FALSE, severity = getOption("assertive.severity", "stop"))

assert_any_numbers_are_whole_numbers(x, tol = 100 * .Machine$double.eps,
  na_ignore = FALSE, severity = getOption("assertive.severity", "stop"))

assert_all_are_whole_numbers(x, tol = 100 * .Machine$double.eps,
  na_ignore = FALSE, severity = getOption("assertive.severity", "stop"))

assert_any_are_whole_numbers(x, tol = 100 * .Machine$double.eps,
  na_ignore = FALSE, severity = getOption("assertive.severity", "stop"))

is_whole_number(x, tol = 100 * .Machine$double.eps,
  .xname = get_name_in_parent(x))
}
\arguments{
\item{x}{Input to check.}

\item{tol}{Differences smaller than \code{tol} are not considered.}

\item{na_ignore}{A logical value.  If \code{FALSE}, \code{NA} values
cause an error; otherwise they do not.  Like \code{na.rm} in many
stats package functions, except that the position of the failing
values does not change.}

\item{severity}{How severe should the consequences of the assertion be?
Either \code{"stop"}, \code{"warning"}, \code{"message"}, or \code{"none"}.}

\item{.xname}{Not intended to be used directly.}
}
\value{
\code{TRUE} if the input is a whole number.
}
\description{
Checks that the (probably floating point) input is a whole number.
}
\note{
The term whole number is used to distinguish from integer in
that the input \code{x} need not have type \code{integer}.  In fact
it is expected that \code{x} will be \code{numeric}.
}
\examples{
# 1, plus or minus a very small number
x <- 1 + c(0, .Machine$double.eps, -.Machine$double.neg.eps)
# By default, you get a bit of tolerance for rounding errors
is_whole_number(x)
# Set the tolerance to zero for exact matching.
is_whole_number(x, tol = 0)
}
\seealso{
\code{is_divisible_by}
}

